@@ -55,9 +55,11 @@
 #include "e-util/e-popup.h"
 #include "e-util/e-error.h"
 
-
+#if !GTK_CHECK_VERSION(2,16,0)
+#define gtk_status_icon_set_tooltip_text gtk_status_icon_set_tooltip
+#endif
 
-#define d(x) x
+#define d(x)
 
 /* The dialog with alarm nofications */
 static AlarmNotificationsDialog *alarm_notifications_dialog = NULL;
@@ -477,7 +479,7 @@ add_component_alarms (ClientAlarms *ca, ECalComponentAlarms *alarms)
 		ECalComponentAlarmInstance *instance;
 		gpointer alarm_id;
 		QueuedAlarm *qa;
-		time_t tnow = time(NULL);
+		d(time_t tnow = time(NULL));
 
 		instance = l->data;
 
@@ -1528,10 +1530,10 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 		char *tip;
 
 		tip =  g_strdup_printf (_("You have %d alarms"), g_list_length (tray_icons_list));
-		gtk_status_icon_set_tooltip (tray_icon, tip);
+		gtk_status_icon_set_tooltip_text (tray_icon, tip);
 	}
 	else {
-		gtk_status_icon_set_tooltip (tray_icon, str);
+		gtk_status_icon_set_tooltip_text (tray_icon, str);
 	}
 
 	g_free (start_str);
