@@ -1,23 +1,24 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* itip-attendee.h
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+/*
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		JP Rosevear <jpr@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Author: JP Rosevear
  */
 
 #ifndef _E_MEETING_TYPES_H_
@@ -47,11 +48,12 @@ typedef struct _EMeetingFreeBusyPeriod     EMeetingFreeBusyPeriod;
    used as for loop counters, so they should start at 0 and be ordered. */
 typedef enum
 {
-	E_MEETING_FREE_BUSY_TENTATIVE       = 0,
+	E_MEETING_FREE_BUSY_TENTATIVE		= 0,
 	E_MEETING_FREE_BUSY_OUT_OF_OFFICE	= 1,
 	E_MEETING_FREE_BUSY_BUSY		= 2,
+	E_MEETING_FREE_BUSY_FREE		= 3,
 
-	E_MEETING_FREE_BUSY_LAST		= 3
+	E_MEETING_FREE_BUSY_LAST		= 4
 } EMeetingFreeBusyType;
 
 /* This is our representation of a time. We use a GDate to store the day,
