@@ -1,22 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Michael Zucchi <notzed@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright 2004 Ximian, Inc. (www.ximian.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -92,16 +92,16 @@ e_profile_event_get_type(void)
 
 /**
  * e_profile_event_peek:
- * @void: 
- * 
+ * @void:
+ *
  * Get the singular instance of the profile event handler.
- * 
- * Return value: 
+ *
+ * Return value:
  **/
 EProfileEvent *e_profile_event_peek(void)
 {
 	if (e_profile_event == NULL) {
-		e_profile_event = g_object_new(e_profile_event_get_type(), 0);
+		e_profile_event = g_object_new(e_profile_event_get_type(), NULL);
 		e_event_construct(&e_profile_event->popup, "org.gnome.evolution.profile.events");
 	}
 
@@ -134,11 +134,12 @@ e_profile_event_emit(const char *id, const char *uid, guint32 flags)
 	e_event_emit((EEvent *)epe, "event", (EEventTarget *)t);
 }
 #else
+/* simply keep macro from header file expand to "nothing".
 #undef e_profile_event_emit
-void
+static void
 e_profile_event_emit(const char *id, const char *uid, guint32 flags)
 {
-}
+}*/
 #endif
 
 /* ********************************************************************** */
@@ -150,12 +151,12 @@ static const EEventHookTargetMask emeh_profile_masks[] = {
 	{ "start", E_PROFILE_EVENT_START },
 	{ "end", E_PROFILE_EVENT_END },
 	{ "cancel", E_PROFILE_EVENT_CANCEL },
-	{ 0 }
+	{ NULL }
 };
 
 static const EEventHookTargetMap emeh_targets[] = {
 	{ "event", E_PROFILE_EVENT_TARGET, emeh_profile_masks },
-	{ 0 }
+	{ NULL }
 };
 
 static void
@@ -184,7 +185,7 @@ GType
 e_profile_event_hook_get_type(void)
 {
 	static GType type = 0;
-	
+
 	if (!type) {
 		static const GTypeInfo info = {
 			sizeof(EProfileEventHookClass), NULL, NULL, (GClassInitFunc) emeh_class_init, NULL, NULL,
@@ -194,6 +195,6 @@ e_profile_event_hook_get_type(void)
 		emeh_parent_class = g_type_class_ref(e_event_hook_get_type());
 		type = g_type_register_static(e_event_hook_get_type(), "EProfileEventHook", &info, 0);
 	}
-	
+
 	return type;
 }
