@@ -38,14 +38,17 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
-#include <libgnome/gnome-help.h>
-#include <libgnome/gnome-util.h>
+#include <libgnome/gnome-init.h>
+
+#include <camel/camel-url.h>
 
 #ifdef G_OS_WIN32
 #include <windows.h>
 #endif
 
 #include <libedataserver/e-data-server-util.h>
+#include <libedataserver/e-categories.h>
+#include "filter/filter-option.h"
 #include "e-util.h"
 #include "e-util-private.h"
 
@@ -69,6 +72,78 @@ e_get_user_data_dir (void)
 	return dirname;
 }
 
+/**
+ * e_get_accels_filename:
+ *
+ * Returns the name of the user data file containing custom keyboard
+ * accelerator specifications.
+ *
+ * Returns: filename for accelerator specifications
+ **/
+const gchar *
+e_get_accels_filename (void)
+{
+	static gchar *filename = NULL;
+
+	if (G_UNLIKELY (filename == NULL))
+		filename = g_build_filename (
+			gnome_user_dir_get (),
+			"accels", PACKAGE, NULL);
+
+	return filename;
+}
+
+/**
+ * e_show_uri:
+ * @parent: a parent #GtkWindow or %NULL
+ * @uri: the URI to show
+ *
+ * Launches the default application to show the given URI.  The URI must
+ * be of a form understood by GIO.  If the URI cannot be shown, it presents
+ * a dialog describing the error.  The dialog is set as transient to @parent
+ * if @parent is non-%NULL.
+ **/
+void
+e_show_uri (GtkWindow *parent,
+            const gchar *uri)
+{
+	GtkWidget *dialog;
+	GdkScreen *screen = NULL;
+	GError *error = NULL;
+	gchar *decoded_uri;
+	guint32 timestamp;
+
+	g_return_if_fail (uri != NULL);
+
+	timestamp = gtk_get_current_event_time ();
+
+	if (parent != NULL)
+		screen = gtk_widget_get_screen (GTK_WIDGET (parent));
+
+	decoded_uri = g_strdup (uri);
+	camel_url_decode (decoded_uri);
+
+	if (gtk_show_uri (screen, decoded_uri, timestamp, &error))
+		goto exit;
+
+	dialog = gtk_message_dialog_new_with_markup (
+		parent, GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+		"<big><b>%s</b></big>",
+		_("Could not open the link."));
+
+	gtk_message_dialog_format_secondary_text (
+		GTK_MESSAGE_DIALOG (dialog), "%s", error->message);
+
+	gtk_dialog_run (GTK_DIALOG (dialog));
+
+	gtk_widget_destroy (dialog);
+	g_error_free (error);
+
+exit:
+	g_free (decoded_uri);
+}
+
 /**
  * e_display_help:
  * @parent: a parent #GtkWindow or %NULL
@@ -83,11 +158,23 @@ void
 e_display_help (GtkWindow *parent,
                 const gchar *link_id)
 {
+	GString *uri;
 	GtkWidget *dialog;
+	GdkScreen *screen = NULL;
 	GError *error = NULL;
+	guint32 timestamp;
 
-	if (gnome_help_display ("evolution.xml", link_id, &error))
-		return;
+	uri = g_string_new ("ghelp:" PACKAGE);
+	timestamp = gtk_get_current_event_time ();
+
+	if (parent != NULL)
+		screen = gtk_widget_get_screen (GTK_WIDGET (parent));
+
+	if (link_id != NULL)
+		g_string_append_printf (uri, "?%s", link_id);
+
+	if (gtk_show_uri (screen, uri->str, timestamp, &error))
+		goto exit;
 
 	dialog = gtk_message_dialog_new_with_markup (
 		parent, GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -102,6 +189,9 @@ e_display_help (GtkWindow *parent,
 
 	gtk_widget_destroy (dialog);
 	g_error_free (error);
+
+exit:
+	g_string_free (uri, TRUE);
 }
 
 /**
@@ -332,94 +422,6 @@ e_format_number (gint number)
 	}
 }
 
-static gchar *
-do_format_number_as_float (gdouble number)
-{
-	GList *iterator, *list = NULL;
-	struct lconv *locality;
-	gint char_length = 0;
-	gint group_count = 0;
-	gchar *grouping;
-	gint last_count = 3;
-	gint divider;
-	gchar *value;
-	gchar *value_iterator;
-	gdouble fractional;
-
-	locality = localeconv();
-	grouping = locality->grouping;
-	while (number >= 1.0) {
-		gchar *group;
-		switch (*grouping) {
-		default:
-			last_count = *grouping;
-			grouping++;
-			/* Fall through */
-		case 0:
-			divider = epow10(last_count);
-			number /= divider;
-			fractional = modf (number, &number);
-			fractional *= divider;
-			fractional = floor (fractional);
-
-			if (number >= 1.0) {
-				group = g_strdup_printf("%0*d", last_count, (int) fractional);
-			} else {
-				group = g_strdup_printf("%d", (gint) fractional);
-			}
-			break;
-		case CHAR_MAX:
-			divider = epow10(last_count);
-			number /= divider;
-			fractional = modf (number, &number);
-			fractional *= divider;
-			fractional = floor (fractional);
-
-			while (number >= 1.0) {
-				group = g_strdup_printf("%0*d", last_count, (gint) fractional);
-
-				char_length += strlen(group);
-				list = g_list_prepend(list, group);
-				group_count ++;
-
-				divider = epow10(last_count);
-				number /= divider;
-				fractional = modf (number, &number);
-				fractional *= divider;
-				fractional = floor (fractional);
-			}
-
-			group = g_strdup_printf("%d", (gint) fractional);
-			break;
-		}
-		char_length += strlen(group);
-		list = g_list_prepend(list, group);
-		group_count ++;
-	}
-
-	if (list) {
-		value = g_new(gchar, 1 + char_length + (group_count - 1) * strlen(locality->thousands_sep));
-
-		iterator = list;
-		value_iterator = value;
-
-		strcpy(value_iterator, iterator->data);
-		value_iterator += strlen(iterator->data);
-		for (iterator = iterator->next; iterator; iterator = iterator->next) {
-			strcpy(value_iterator, locality->thousands_sep);
-			value_iterator += strlen(locality->thousands_sep);
-
-			strcpy(value_iterator, iterator->data);
-			value_iterator += strlen(iterator->data);
-		}
-		g_list_foreach (list, (GFunc) g_free, NULL);
-		g_list_free (list);
-		return value;
-	} else {
-		return g_strdup("0");
-	}
-}
-
 /* Perform a binary search for key in base which has nmemb elements
    of size bytes each.  The comparisons are done by (*compare)().  */
 void
@@ -1312,3 +1314,23 @@ e_util_read_file (const char *filename, gboolean filename_is_uri, char **buffer,
 	return res;
 }
 
+GSList *
+e_util_get_category_filter_options (void)
+{
+	GSList *res = NULL;
+	GList *clist, *l;
+
+	clist = e_categories_get_list ();
+	for (l = clist; l; l = l->next) {
+		const char *cname = l->data;
+		struct _filter_option *fo = g_new0 (struct _filter_option, 1);
+
+		fo->title = g_strdup (cname);
+		fo->value = g_strdup (cname);
+		res = g_slist_prepend (res, fo);
+	}
+
+	g_list_free (clist);
+
+	return g_slist_reverse (res);
+}
